@@ -171,7 +171,7 @@ final class ArrayEncoding {
     int countNulls(A array) {
       int nulls = 0;
       final int arrayLength = Array.getLength(array);
-      for (int i = 0; i < arrayLength; ++i) {
+      for (int i = 0; i < arrayLength; i++) {
         if (Array.get(array, i) == null) {
           ++nulls;
         }
@@ -245,7 +245,7 @@ final class ArrayEncoding {
     @Override
     final int countNulls(N[] array) {
       int count = 0;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (array[i] == null) {
           ++count;
         }
@@ -296,7 +296,7 @@ final class ArrayEncoding {
       final byte[] bytes = new byte[length];
 
       int idx = offset;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (array[i] == null) {
           ByteConverter.int4(bytes, idx, -1);
           idx += 4;
@@ -330,7 +330,7 @@ final class ArrayEncoding {
     @Override
     public final void appendArray(StringBuilder sb, char delim, N[] array) {
       sb.append('{');
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (i != 0) {
           sb.append(delim);
         }
@@ -408,7 +408,7 @@ final class ArrayEncoding {
     @Override
     final byte[] toSingleDimensionBinaryRepresentation(BaseConnection connection, A array)
         throws SQLException, SQLFeatureNotSupportedException {
-      final int length = ((fieldSize + 4) * Array.getLength(array));
+      final int length = (fieldSize + 4) * Array.getLength(array);
       final byte[] bytes = new byte[length];
 
       write(array, bytes, 0);
@@ -438,7 +438,7 @@ final class ArrayEncoding {
     @Override
     public void appendArray(StringBuilder sb, char delim, long[] array) {
       sb.append('{');
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (i > 0) {
           sb.append(delim);
         }
@@ -453,7 +453,7 @@ final class ArrayEncoding {
     @Override
     protected void write(long[] array, byte[] bytes, int offset) {
       int idx = offset;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         bytes[idx + 3] = 8;
         ByteConverter.int8(bytes, idx + 4, array[i]);
         idx += 12;
@@ -479,7 +479,7 @@ final class ArrayEncoding {
     @Override
     public void appendArray(StringBuilder sb, char delim, int[] array) {
       sb.append('{');
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (i > 0) {
           sb.append(delim);
         }
@@ -494,7 +494,7 @@ final class ArrayEncoding {
     @Override
     protected void write(int[] array, byte[] bytes, int offset) {
       int idx = offset;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         bytes[idx + 3] = 4;
         ByteConverter.int4(bytes, idx + 4, array[i]);
         idx += 8;
@@ -520,7 +520,7 @@ final class ArrayEncoding {
     @Override
     public void appendArray(StringBuilder sb, char delim, short[] array) {
       sb.append('{');
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (i > 0) {
           sb.append(delim);
         }
@@ -535,7 +535,7 @@ final class ArrayEncoding {
     @Override
     protected void write(short[] array, byte[] bytes, int offset) {
       int idx = offset;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         bytes[idx + 3] = 2;
         ByteConverter.int2(bytes, idx + 4, array[i]);
         idx += 6;
@@ -564,7 +564,7 @@ final class ArrayEncoding {
     @Override
     public void appendArray(StringBuilder sb, char delim, double[] array) {
       sb.append('{');
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (i > 0) {
           sb.append(delim);
         }
@@ -582,7 +582,7 @@ final class ArrayEncoding {
     @Override
     protected void write(double[] array, byte[] bytes, int offset) {
       int idx = offset;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         bytes[idx + 3] = 8;
         ByteConverter.float8(bytes, idx + 4, array[i]);
         idx += 12;
@@ -611,7 +611,7 @@ final class ArrayEncoding {
     @Override
     public void appendArray(StringBuilder sb, char delim, float[] array) {
       sb.append('{');
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (i > 0) {
           sb.append(delim);
         }
@@ -629,7 +629,7 @@ final class ArrayEncoding {
     @Override
     protected void write(float[] array, byte[] bytes, int offset) {
       int idx = offset;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         bytes[idx + 3] = 4;
         ByteConverter.float4(bytes, idx + 4, array[i]);
         idx += 8;
@@ -658,7 +658,7 @@ final class ArrayEncoding {
     @Override
     public void appendArray(StringBuilder sb, char delim, boolean[] array) {
       sb.append('{');
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (i > 0) {
           sb.append(delim);
         }
@@ -673,7 +673,7 @@ final class ArrayEncoding {
     @Override
     protected void write(boolean[] array, byte[] bytes, int offset) {
       int idx = offset;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         bytes[idx + 3] = 1;
         ByteConverter.bool(bytes, idx + 4, array[i]);
         idx += 5;
@@ -715,7 +715,7 @@ final class ArrayEncoding {
       final byte[] bytes = new byte[length];
 
       int idx = offset;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (array[i] == null) {
           ByteConverter.int4(bytes, idx, -1);
           idx += 4;
@@ -750,7 +750,7 @@ final class ArrayEncoding {
     @Override
     public void appendArray(StringBuilder sb, char delim, Boolean[] array) {
       sb.append('{');
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (i != 0) {
           sb.append(delim);
         }
@@ -773,7 +773,7 @@ final class ArrayEncoding {
     @Override
     int countNulls(String[] array) {
       int count = 0;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (array[i] == null) {
           ++count;
         }
@@ -813,7 +813,7 @@ final class ArrayEncoding {
     @Override
     public void appendArray(StringBuilder sb, char delim, String[] array) {
       sb.append('{');
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (i > 0) {
           sb.append(delim);
         }
@@ -856,7 +856,7 @@ final class ArrayEncoding {
         baos.write(buffer);
 
         final Encoding encoding = connection.getEncoding();
-        for (int i = 0; i < array.length; ++i) {
+        for (int i = 0; i < array.length; i++) {
           final String string = array[i];
           if (string != null) {
             final byte[] encoded;
@@ -893,7 +893,7 @@ final class ArrayEncoding {
         final ByteArrayOutputStream baos = new ByteArrayOutputStream(Math.min(1024, (array.length * 32) + 20));
         final byte[] buffer = new byte[4];
         final Encoding encoding = connection.getEncoding();
-        for (int i = 0; i < array.length; ++i) {
+        for (int i = 0; i < array.length; i++) {
           final String string = array[i];
           if (string != null) {
             final byte[] encoded;
@@ -927,8 +927,8 @@ final class ArrayEncoding {
     /**
      * The possible characters to use for representing hex binary data.
      */
-    private final char[] hexDigits = new char[] { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd',
-        'e', 'f' };
+    private final char[] hexDigits = new char[]{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd',
+        'e', 'f'};
 
     /**
      * {@inheritDoc}
@@ -940,7 +940,7 @@ final class ArrayEncoding {
       assert oid == arrayOid;
 
       int length = 20;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         length += 4;
         if (array[i] != null) {
           length += array[i].length;
@@ -971,7 +971,7 @@ final class ArrayEncoding {
     byte[] toSingleDimensionBinaryRepresentation(BaseConnection connection, byte[][] array)
         throws SQLException, SQLFeatureNotSupportedException {
       int length = 0;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         length += 4;
         if (array[i] != null) {
           length += array[i].length;
@@ -989,7 +989,7 @@ final class ArrayEncoding {
     @Override
     int countNulls(byte[][] array) {
       int nulls = 0;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (array[i] == null) {
           ++nulls;
         }
@@ -999,7 +999,7 @@ final class ArrayEncoding {
 
     private void write(byte[][] array, byte[] bytes, int offset) {
       int idx = offset;
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (array[i] != null) {
           ByteConverter.int4(bytes, idx, array[i].length);
           idx += 4;
@@ -1018,14 +1018,14 @@ final class ArrayEncoding {
     @Override
     public void appendArray(StringBuilder sb, char delim, byte[][] array) {
       sb.append('{');
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (i > 0) {
           sb.append(delim);
         }
 
         if (array[i] != null) {
           sb.append("\"\\\\x");
-          for (int j = 0; j < array[i].length; ++j) {
+          for (int j = 0; j < array[i].length; j++) {
             byte b = array[i][j];
 
             // get the value for the left 4 bits (drop sign)
@@ -1072,7 +1072,7 @@ final class ArrayEncoding {
     @Override
     public void appendArray(StringBuilder sb, char delim, Object[] array) {
       sb.append('{');
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (i > 0) {
           sb.append(delim);
         }
@@ -1097,7 +1097,7 @@ final class ArrayEncoding {
   };
 
   @SuppressWarnings("rawtypes")
-  private static final Map<Class, AbstractArrayEncoder> ARRAY_CLASS_TO_ENCODER = new HashMap<Class, AbstractArrayEncoder>(
+  private static final Map<Class, AbstractArrayEncoder> ARRAY_CLASS_TO_ENCODER = new HashMap<>(
       (int) (14 / .75) + 1);
 
   static {
@@ -1128,7 +1128,7 @@ final class ArrayEncoding {
    *           if <i>array</i> is not a supported type.
    * @see ArrayEncoding.ArrayEncoder#supportBinaryRepresentation(int)
    */
-  @SuppressWarnings({ "unchecked", "rawtypes" })
+  @SuppressWarnings({"unchecked", "rawtypes"})
   public static <A extends Object> ArrayEncoder<A> getArrayEncoder(A array) throws PSQLException {
     final Class<?> arrayClazz = array.getClass();
     Class<?> subClazz = arrayClazz.getComponentType();
@@ -1213,7 +1213,7 @@ final class ArrayEncoding {
     @Override
     public void appendArray(StringBuilder sb, char delim, A[] array) {
       sb.append('{');
-      for (int i = 0; i < array.length; ++i) {
+      for (int i = 0; i < array.length; i++) {
         if (i > 0) {
           sb.append(delim);
         }
@@ -1241,7 +1241,7 @@ final class ArrayEncoding {
       final byte[] buffer = new byte[4];
 
       boolean hasNulls = false;
-      for (int i = 0; !hasNulls && i < array.length; ++i) {
+      for (int i = 0; !hasNulls && i < array.length; i++) {
         if (support.countNulls(array[i]) > 0) {
           hasNulls = true;
         }
@@ -1271,7 +1271,7 @@ final class ArrayEncoding {
         ByteConverter.int4(buffer, 0, 1);
         baos.write(buffer);
 
-        for (int i = 0; i < array.length; ++i) {
+        for (int i = 0; i < array.length; i++) {
           baos.write(support.toSingleDimensionBinaryRepresentation(connection, array[i]));
         }
 
@@ -1289,7 +1289,7 @@ final class ArrayEncoding {
    * Wraps an {@link AbstractArrayEncoder} implementation and provides support for
    * 2 or more dimensions using recursion.
    */
-  @SuppressWarnings({ "unchecked", "rawtypes" })
+  @SuppressWarnings({"unchecked", "rawtypes"})
   private static final class RecursiveArrayEncoder implements ArrayEncoder {
 
     private final AbstractArrayEncoder support;
@@ -1336,7 +1336,7 @@ final class ArrayEncoding {
 
       if (depth > 1) {
         sb.append('{');
-        for (int i = 0, j = Array.getLength(array); i < j; ++i) {
+        for (int i = 0, j = Array.getLength(array); i < j; i++) {
           if (i > 0) {
             sb.append(delim);
           }
@@ -1358,7 +1358,7 @@ final class ArrayEncoding {
 
     private boolean hasNulls(Object array, int depth) {
       if (depth > 1) {
-        for (int i = 0, j = Array.getLength(array); i < j; ++i) {
+        for (int i = 0, j = Array.getLength(array); i < j; i++) {
           if (hasNulls(Array.get(array, i), depth - 1)) {
             return true;
           }
@@ -1422,7 +1422,7 @@ final class ArrayEncoding {
         baos.write(buffer);
       }
 
-      for (int i = 0; i < length; ++i) {
+      for (int i = 0; i < length; i++) {
         final Object subArray = Array.get(array, i);
         if (depth > 2) {
           writeArray(connection, buffer, baos, subArray, depth - 1, i == 0);
