@@ -5,10 +5,10 @@
 
 package org.postgresql.core.v3;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.sql.SQLException;
 
@@ -18,11 +18,11 @@ import java.sql.SQLException;
  * @author Jeremy Whiting jwhiting@redhat.com
  *
  */
-public class V3ParameterListTests {
+class V3ParameterListTests {
   private TypeTransferModeRegistry transferModeRegistry;
 
-  @Before
-  public void setUp() throws Exception {
+  @BeforeEach
+  void setUp() throws Exception {
     transferModeRegistry = new TypeTransferModeRegistry() {
         @Override
         public boolean useBinaryForSend(int oid) {
@@ -44,7 +44,7 @@ public class V3ParameterListTests {
    *           raised exception if setting parameter fails.
    */
   @Test
-  public void testMergeOfParameterLists() throws SQLException {
+  void mergeOfParameterLists() throws SQLException {
     SimpleParameterList s1SPL = new SimpleParameterList(8, transferModeRegistry);
     s1SPL.setIntParameter(1, 1);
     s1SPL.setIntParameter(2, 2);
@@ -58,8 +58,7 @@ public class V3ParameterListTests {
     s2SPL.setIntParameter(4, 8);
 
     s1SPL.appendAll(s2SPL);
-    assertEquals("Expected string representation of values does not match outcome.",
-        "<[('1'::int4) ,('2'::int4) ,('3'::int4) ,('4'::int4) ,('5'::int4) ,('6'::int4) ,('7'::int4) ,('8'::int4)]>", s1SPL.toString());
-
+    assertEquals(
+        "<[('1'::int4) ,('2'::int4) ,('3'::int4) ,('4'::int4) ,('5'::int4) ,('6'::int4) ,('7'::int4) ,('8'::int4)]>", s1SPL.toString(), "Expected string representation of values does not match outcome.");
   }
 }
